@@ -58,8 +58,8 @@ public:
 	AudioCodec *getByInfo(Info &info);
 	AudioCodec *getByFormat(const char *format);	
 	
-	unsigned encode(Linear data, void *dest, unsigned samples, unsigned bufsize);
-	unsigned decode(Linear data, void *source, unsigned samples, unsigned bufsize);
+	unsigned encode(Linear data, void *dest, unsigned samples, bool buffered);
+	unsigned decode(Linear data, void *source, unsigned samples, bool buffered);
 
 	GSMCodec();
 	~GSMCodec();
@@ -93,7 +93,7 @@ AudioCodec *GSMCodec::getByFormat(const char *format)
 	return (AudioCodec *)new GSMCodec();
 }
 
-unsigned GSMCodec::encode(Linear from, void *dest, unsigned samples, unsigned bufsize)
+unsigned GSMCodec::encode(Linear from, void *dest, unsigned samples, bool buffered)
 {
 	unsigned count = samples / 160;
 	unsigned result = count * 33;
@@ -111,7 +111,7 @@ unsigned GSMCodec::encode(Linear from, void *dest, unsigned samples, unsigned bu
 	return result;
 }
 
-unsigned GSMCodec::decode(Linear dest, void *from, unsigned samples, unsigned bufsize)
+unsigned GSMCodec::decode(Linear dest, void *from, unsigned samples, bool buffered)
 {
 	unsigned count = samples / 160;
 	unsigned result = count * 33;
