@@ -4,7 +4,7 @@
  * details.  THERE IS ABSOLUTELY NO WARRANTY FOR THIS SOFTWARE.
  */
 
-/* $Header: /cvsroot/gnutelephony/testing/ccaudio2/gsm/code.c,v 1.2 2005/07/29 20:11:13 dyfet Exp $ */
+/* $Header: /cvsroot/gnutelephony/testing/ccaudio2/gsm/code.c,v 1.3 2006/04/05 11:37:00 dyfet Exp $ */
 
 #include	"config.h"
 
@@ -87,7 +87,7 @@ void Gsm_Coder P8((S,s,LARc,Nc,bc,Mc,xmaxc,xMc),
 		{ register int i;
 		  register longword ltmp;
 		  for (i = 0; i <= 39; i++)
-			dp[ i ] = GSM_ADD( e[5 + i], dpp[i] );
+			dp[ i ] = (word)GSM_ADD( e[5 + i], dpp[i] );
 		}
 		dp  += 40;
 		dpp += 40;
