@@ -81,6 +81,8 @@
 #include <netinet/in.h>
 #endif
 
+#include <ctime>
+
 namespace ost {
 
 #define	AUDIO_SIGNED_LINEAR_RAW	1
@@ -477,12 +479,13 @@ public:
 
 	/**
 	 * Test if the audio encoding format must be packetized (that
-	 * is, has irregular sized frames).
+	 * is, has irregular sized frames) and must be processed
+	 * only through buffered codecs.
 	 *
 	 * @return true if packetized audio.
 	 * @param encoding format.
 	 */
-	static bool isPacket(Encoding encoding);
+	static bool isBuffered(Encoding encoding);
 
 	/**
 	 * Test if the audio encoding format is a mono format.
@@ -1207,7 +1210,7 @@ public:
 	 * computations.
 	 *
 	 * @return age in seconds.
-	 * /
+	 */
 	time_t getAge(void);
 
 	/**
@@ -1808,21 +1811,21 @@ public:
 	 * @param number of bytes written.
 	 * @param buffer linear sample buffer to use.
 	 * @param dest buffer to store encoded results.
-	 * @param number of linear samples.
-	 * @param size of destination buffer.
+	 * @param number of samples or buffered bytes.
+	 * @param true if buffered mode.
 	 */
-	virtual unsigned encode(Linear buffer, void *dest, unsigned number = 0, unsigned bufsize = 0) = 0;
+	virtual unsigned encode(Linear buffer, void *dest, unsigned number = 0, bool buffered = false) = 0;
 
 	/**
 	 * Decode the sample frame into linear samples.
 	 *
-	 * @return number of bytes scanned.
+	 * @return number of bytes scanned or returned
 	 * @param buffer sample buffer to save linear samples into.
 	 * @param source for encoded data.
-	 * @param number of samples to extract.
-	 * @patam size of source buffer.
+	 * @param number of samples to extract or bytes to buffer.
+	 * @patam true if buffered mode.
 	 */
-	virtual unsigned decode(Linear buffer, void *source, unsigned number = 0, unsigned bufsize = 0) = 0;
+	virtual unsigned decode(Linear buffer, void *source, unsigned number = 0, bool buffered = false) = 0;
 
 	/**
 	 * Get an info description for this codec.
