@@ -196,8 +196,9 @@ Audio::Encoding Audio::getMono(Encoding encoding)
 		return pcm16Mono;
 	case pcm32Stereo:
 		return pcm32Mono;
+	default:
+		return encoding;
 	}
-	return encoding;
 }
 
 Audio::Encoding Audio::getStereo(Encoding encoding)
@@ -217,8 +218,9 @@ Audio::Encoding Audio::getStereo(Encoding encoding)
 		return pcm16Stereo;
 	case pcm32Mono:
 		return pcm32Stereo;
+	default:
+		return unknownEncoding;
 	}
-	return unknownEncoding;
 }
 
 Audio::Encoding Audio::getEncoding(const char *name)
@@ -296,8 +298,9 @@ const char *Audio::getMIME(Info &info)
 		{
 		case g721ADPCM:
 			return "audio/x-adpcm";
+		default:
+			return "audio/basic";
 		}
-		return "audio/basic";
 	}
 
 	if(info.format == riff)
@@ -316,8 +319,9 @@ const char *Audio::getMIME(Info &info)
 		return "audio/l16";
 	case voxADPCM:
 		return "audio/x-vox";
+	default:
+		return NULL;
 	}
-	return NULL;
 }
 
 const char *Audio::getName(Encoding encoding)
@@ -370,11 +374,12 @@ const char *Audio::getName(Encoding encoding)
 	case speexVoice:
 	case speexAudio:
 		return "speex";
+	default:
+		return "unknown";
 	}
-	return "unknown";
 }
 
-bool Audio::isPacket(Encoding encoding)
+bool Audio::isBuffered(Encoding encoding)
 {
 	switch(encoding)
 	{
@@ -382,8 +387,9 @@ bool Audio::isPacket(Encoding encoding)
 	case mp2Audio:
 	case mp3Audio:
 		return true;
+	default:
+		return false;
 	}
-	return false;
 } 
 
 bool Audio::isLinear(Encoding encoding)
@@ -395,8 +401,9 @@ bool Audio::isLinear(Encoding encoding)
 	case pcm16Stereo:
 	case pcm16Mono:
 		return true;
+	default:
+		return false;
 	}
-	return false;
 }
 
 Audio::Level Audio::getImpulse(Encoding encoding, void *buffer, unsigned samples)
@@ -445,8 +452,9 @@ Audio::Level Audio::getImpulse(Encoding encoding, void *buffer, unsigned samples
 				sum += mb;
 		}
 		return (Level)(sum / count);
+	default:
+		return -1;
 	}
-	return -1;
 }
 
 Audio::Level Audio::getImpulse(Info &info, void *buffer, unsigned samples)
@@ -522,8 +530,9 @@ Audio::Level Audio::getImpulse(Info &info, void *buffer, unsigned samples)
 				sum += mb;
 		}
 		return (Level)(sum / count);
+	default:
+		return -1;
 	}
-	return -1;
 }
 
 Audio::Level Audio::getPeak(Encoding encoding, void *buffer, unsigned samples)
@@ -572,8 +581,9 @@ Audio::Level Audio::getPeak(Encoding encoding, void *buffer, unsigned samples)
 				max = mb;
 		}
 		return max;
+	default:
+		return -1;
 	}
-	return -1;
 }
 
 Audio::Level Audio::getPeak(Info &info, void *buffer, unsigned samples)
@@ -656,8 +666,9 @@ Audio::Level Audio::getPeak(Info &info, void *buffer, unsigned samples)
 				max = mb;
 		}
 		return max;
+	default:
+		return -1;
 	}
-	return -1;
 }
 
 void Audio::swapEncoded(Info &info, Encoded buffer, size_t bytes)
@@ -732,8 +743,9 @@ bool Audio::swapEndian(Encoding encoding, void *buffer, unsigned samples)
 			s4 += 4;
 		}
 		return false;
+	default:
+		return true;
 	}
-	return true;
 }
 
 bool Audio::swapEndian(Info &info, void *buffer, unsigned samples)
@@ -786,8 +798,9 @@ bool Audio::swapEndian(Info &info, void *buffer, unsigned samples)
 			s4 += 4;
 		}
 		return false;
+	default:
+		return true;
 	}
-	return true;
 }
 
 
@@ -803,9 +816,9 @@ bool Audio::isEndian(Encoding encoding)
 	case pcm16Mono:
 		if(__BYTE_ORDER != __LITTLE_ENDIAN)
 			return false;
-		break;
+	default:
+		return true;
 	}
-	return true;
 }
 
 bool Audio::isEndian(Info &info)
@@ -820,8 +833,9 @@ bool Audio::isEndian(Info &info)
 	case pcm32Mono:
 		if(info.order && __BYTE_ORDER != info.order)
 			return false;
+	default:
+		return true;
 	}
-	return true;
 }
 
 Audio::timeout_t Audio::getFraming(Info &info, timeout_t timeout)
@@ -864,6 +878,7 @@ Audio::timeout_t Audio::getFraming(Encoding encoding, timeout_t timeout)
 	case sx96Voice:
 	case sx73Voice:
 		fa = 15;
+	default:
 		break;
 	}
 	if(!timeout)
@@ -1054,8 +1069,9 @@ size_t Audio::maxFramesize(Info &info)
 	case mp2Audio:
 	case mp3Audio:
 		return 1735;
+	default:
+		return info.framesize;
 	}
-	return info.framesize;
 }
 
 size_t Audio::toBytes(Info &info, unsigned long samples)
