@@ -135,7 +135,8 @@ void OSSAudioDevice::flush(void)
 	{
 		for(pos = sendpos; pos < bufsize / 2; ++pos)
 			sendbuf[pos] = 0;
-		::write(dsp, sendbuf, bufsize);
+		if(::write(dsp, sendbuf, bufsize) < bufsize)
+			abort();
 	}
 
 	sendpos = 0;
@@ -260,7 +261,7 @@ unsigned OSSAudioDevice::getSamples(Linear samples, unsigned count)
 
 unsigned OSSAudioDevice::putSamples(Linear samples, unsigned count)
 {
-	unsigned total = 0, fill;
+	unsigned total = 0, fill = 0;
 
 	if(!enabled)
 		return 0;
